summaryrefslogtreecommitdiffstatshomepage
diff options
context:
space:
mode:
author MetalliC <0vetal0@gmail.com>2017-09-14 23:45:53 +0300
committer MetalliC <0vetal0@gmail.com>2017-09-14 23:45:53 +0300
commite9feedc90c2eb433f99665684f01f8c3b8800c1b (patch)
tree47cba4a6d5bf3cb25e6411954be0a8781d8f83a1
parentb88f3b7dd289956634f8717208accc36a816be68 (diff)
new not working clone
--------------------- Shootout Pool Prize (Export) / Shootout Pool The Medal (Japan) Version B -P [Ordyne]
-rw-r--r--src/mame/drivers/naomi.cpp27
-rw-r--r--src/mame/mame.lst5
2 files changed, 28 insertions, 4 deletions
diff --git a/src/mame/mame.lst b/src/mame/mame.lst
index 71b3c0d9fbf..98324446dff 100644
--- a/src/mame/mame.lst
+++ b/src/mame/mame.lst
@@ -28908,8 +28908,9 @@ shaktmsp // 2001.04.04 Shakatto Tambourine Motto Norinori
shangril // 1999.08 Dengen Tenshi Taisen Janshi Shangri-la
shikgam2 // 2003.04 Shikigami No Shiro II / The Castle of Shikigami II
shootopl // 2002.?? Shootout Pool
-shootpl // 2003.?? Shootout Pool The Medal / Shootout Pool Prize (Rev A)
-shootplm // 2004.?? Shootout Pool The Medal Ver. B / Shootout Pool Prize Ver. B
+shootpl // 2003.?? Shootout Pool Prize / Shootout Pool The Medal (Rev A)
+shootplm // 2004.?? Shootout Pool Prize / Shootout Pool The Medal Ver. B
+shootplmp // 2004.?? Shootout Pool Prize / Shootout Pool The Medal Ver. B -P
sl2007 // 2007.07 Shooting Love
slasho // 2000.07 Slashout
slashout // 2000.?? Slashout
diff --git a/src/mame/drivers/naomi.cpp b/src/mame/drivers/naomi.cpp
index a5b308c8620..397e618fc05 100644
--- a/src/mame/drivers/naomi.cpp
+++ b/src/mame/drivers/naomi.cpp
@@ -330,6 +330,7 @@ Ferrari F355 Challenge (twin/deluxe, prototype) no cart 22848P* 21 (64Mb) pre
House of the Dead 2 (prototype) no cart A1E2 21 (64Mb) present 315-6206 present no label on IC42
Inu No Osanpo / Dog Walking (Rev A) 840-0073C 22294A 16 (64Mb) present 315-6206 317-0316-JPN requires 837-13844 JVS IO with DIPSW 1 ON
Samba de Amigo (prototype) no cart * 21*(64Mb) present 315-6206 317-0270-COM * only first 14 flash roms contain game data, instead of EPROM have tiny PCB with 2 flashroms on it
+Shootout Pool Prize Ver.B -P 840-0136C ** 21*(64Mb) present 317-6206 not present * only first 4 flash roms contain game data, ** instead of EPROM have tiny PCB with 2 flashroms on it
Soul Surfer (Rev A) 840-0095C 23838C 21 (64Mb) present 315-6206 not present
Star Horse (live and backup) 840-0055B 23626 17 (64Mb) present 315-6206 not present requires 837-13785 ARCNET&IO BD
Horse Data 840-0034B - 2 (64Mb) present 315-6206 not present not contain game data, used in stack with 840-0121(sound&backup) ROM board as game backup data storage, have JP3 and JP4 in position 2-3
@@ -5661,6 +5662,27 @@ ROM_START( shootplm )
ROM_PARAMETER( ":rom_board:key", "9dbde9cd" )
ROM_END
+// Shootout Pool Prize Ver. B -P
+ROM_START( shootplmp )
+ NAOMI_BIOS
+ NAOMI_DEFAULT_EEPROM
+
+ ROM_REGION( 0x3000000, "rom_board", ROMREGION_ERASEFF)
+ // "IC22" is small PCB with 2 Flash ROMs and printed label:
+ // SHOOTOUT POOL
+ // VER-B
+ // SUM 8ECB
+ // 2003/12/15
+ ROM_LOAD( "ic22", 0x0000000, 0x400000, CRC(0ee293cf) SHA1(5850a6f1730ab6df96368ae44a44e36c0d466a3d) )
+ ROM_LOAD( "ic1", 0x0800000, 0x800000, CRC(4d967bb9) SHA1(160ec430610e2958daa035245c79177dce429206) )
+ ROM_LOAD( "ic2", 0x1000000, 0x800000, CRC(041c3365) SHA1(ca812692df2ba360a9434862387eafd9af9bfb35) )
+ ROM_LOAD( "ic3", 0x1800000, 0x800000, CRC(e14ea5ab) SHA1(797bdc5fdf8d28e66710a8c938730d090b8154f4) )
+ ROM_LOAD( "ic4", 0x2000000, 0x800000, CRC(8d88564a) SHA1(b04a2564b4dd11898896c457996e5aa3e06ac5a9) )
+ // IC5 - IC21 populated, not dumped, not used by game.
+
+ ROM_PARAMETER( ":rom_board:segam2crypt:key", "-1") // 315-5881 not populated
+ROM_END
+
/* Oinori-daimyoujin Matsuri (medal) */
ROM_START( oinori )
NAOMI_BIOS
@@ -10137,10 +10159,11 @@ ROM_END
/* 0122 */ GAME( 2003, shorsepl, shorsep, naomim2, naomi, naomi_state, naomi, ROT0, "Sega", "Star Horse Progress (live, Rev A)", GAME_FLAGS )
/* 0123 */ GAME( 2003, shorsep, naomi, naomim2, naomi, naomi_state, naomi, ROT270,"Sega", "Star Horse Progress (satellite, Rev A)", GAME_FLAGS )
/* 0126 */ GAME( 2003, oinori, naomi, naomim2, naomi, naomi_state, naomi, ROT0, "Sega", "Oinori-daimyoujin Matsuri", GAME_FLAGS )
-/* 0128 */ GAME( 2003, shootpl, naomi, naomim1, naomi, naomi_state, naomi, ROT0, "Sega", "Shootout Pool The Medal / Shootout Pool Prize (Export, Japan, Rev A)", GAME_FLAGS )
+/* 0128 */ GAME( 2003, shootpl, naomi, naomim1, naomi, naomi_state, naomi, ROT0, "Sega", "Shootout Pool Prize (Export) / Shootout Pool The Medal (Japan) (Rev A)", GAME_FLAGS )
/* 0130 */ GAME( 2002, hopper, naomi, naomi, naomi, naomi_state, naomi, ROT0, "Sega", "SWP Hopper Board", GAME_FLAGS )
// 0132 Mushiking 2K3 2ND (Japan)
/* 0136 */ GAME( 2004, shootplm, naomi, naomim1, naomi, naomi_state, naomi, ROT0, "Sega", "Shootout Pool The Medal Version B / Shootout Pool Prize Version B (Export, Japan)", GAME_FLAGS )
/* 0140 */ GAME( 2004, kick4csh, naomi, naomim1, naomi, naomi_state, naomi, ROT0, "Sega", "Kick '4' Cash (Export)", GAME_FLAGS )
/* 0150 */ GAME( 2003, mtkob2, naomi, naomim1, naomi, naomi_state, naomi, ROT0, "Sega", "Mushiking The King Of Beetle (2K3 2ND, World)", GAME_FLAGS ) // not for Japan
/* 0152 */ GAME( 2004, mushi2k4, naomi, naomim2, naomi, naomi_state, naomi, ROT0, "Sega", "Mushiking The King Of Beetles 2004 Second (Japan)", GAME_FLAGS )
@@ -10137,10 +10159,11 @@ ROM_END
/* 0130 */ GAME( 2002, hopper, naomi, naomi, naomi, naomi_state, naomi, ROT0, "Sega", "SWP Hopper Board", GAME_FLAGS )
// 0132 Mushiking 2K3 2ND (Japan)
-/* 0136 */ GAME( 2004, shootplm, naomi, naomim1, naomi, naomi_state, naomi, ROT0, "Sega", "Shootout Pool The Medal Version B / Shootout Pool Prize Version B (Export, Japan)", GAME_FLAGS )
+/* 0136 */ GAME( 2004, shootplm, naomi, naomim1, naomi, naomi_state, naomi, ROT0, "Sega", "Shootout Pool Prize (Export) / Shootout Pool The Medal (Japan) Version B", GAME_FLAGS )
+/* 0136 */ GAME( 2004, shootplmp, shootplm, naomim2, naomi, naomi_state, naomi, ROT0, "Sega", "Shootout Pool Prize (Export) / Shootout Pool The Medal (Japan) Version B -P", GAME_FLAGS )
/* 0140 */ GAME( 2004, kick4csh, naomi, naomim1, naomi, naomi_state, naomi, ROT0, "Sega", "Kick '4' Cash (Export)", GAME_FLAGS )
/* 0150 */ GAME( 2003, mtkob2, naomi, naomim1, naomi, naomi_state, naomi, ROT0, "Sega", "Mushiking The King Of Beetle (2K3 2ND, World)", GAME_FLAGS ) // not for Japan